@@ -29,3 +29,6 @@ if 'milestone_3_p2.txt' in os.listdir('.'):
         else:
             for task_name, task_id in task_name_list[n_task + 1:]:
                 mark_incomplete(task_id)
+else:
+    for task_name, task_id in task_name_list:
+        mark_incomplete(task_id)
\ No newline at end of file
