@@ -16,12 +16,13 @@ task_list = [
 
 if 'milestone_4_p1.txt' in os.listdir('.'):
     errors = get_errors_fails('milestone_4_p1.txt')
-    if 'test_presence_milestone_4' in errors:
-        mark_incomplete(task1_id, errors['test_presence_milestone_4'])
-    elif 'test_presence_class' in errors:
-        mark_incomplete(task1_id, errors['test_presence_class'])
-    for task in task_list[1:]:
-        mark_incomplete(task)
+    if len(errors) != 0:
+        if 'test_presence_milestone_4' in errors:
+            mark_incomplete(task1_id, errors['test_presence_milestone_4'])
+        elif 'test_presence_class' in errors:
+            mark_incomplete(task1_id, errors['test_presence_class'])
+        for task in task_list[1:]:
+            mark_incomplete(task)
 else:
     for task in task_list:
         mark_incomplete(task)
